@@ -5,7 +5,7 @@ Stuff for processing Java.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,12 +27,11 @@ Stuff for processing Java.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/JavaCommon.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Tool/JavaCommon.py  2014/03/02 14:18:15 garyo"
 
 import os
 import os.path
 import re
-import string
 
 java_parsing = 1
 
@@ -60,14 +59,15 @@ if java_parsing:
                           r'\d*\.\d*|[A-Za-z_][\w\$\.]*|<[A-Za-z_]\w+>|' +
                           r'/\*|\*/|\[\])')
 
-    class OuterState:
+    class OuterState(object):
         """The initial state for parsing a Java file for classes,
         interfaces, and anonymous inner classes."""
         def __init__(self, version=default_java_version):
 
-            if not version in ('1.1', '1.2', '1.3','1.4', '1.5', '1.6'):
+            if not version in ('1.1', '1.2', '1.3','1.4', '1.5', '1.6', '1.7',
+                               '5', '6'):
                 msg = "Java version %s not supported" % version
-                raise NotImplementedError, msg
+                raise NotImplementedError(msg)
 
             self.version = version
             self.listClasses = []
@@ -75,6 +75,7 @@ if java_parsing:
             self.stackBrackets = []
             self.brackets = 0
             self.nextAnon = 1
+            self.localClasses = []
             self.stackAnonClassBrackets = []
             self.anonStacksStack = [[0]]
             self.package = None
@@ -125,7 +126,8 @@ if java_parsing:
             self.brackets = self.brackets - 1
             if len(self.stackBrackets) and \
                self.brackets == self.stackBrackets[-1]:
-                self.listOutputs.append(string.join(self.listClasses, '$'))
+                self.listOutputs.append('$'.join(self.listClasses))
+                self.localClasses.pop()
                 self.listClasses.pop()
                 self.anonStacksStack.pop()
                 self.stackBrackets.pop()
@@ -169,14 +171,14 @@ if java_parsing:
             if self.version in ('1.1', '1.2', '1.3', '1.4'):
                 clazz = self.listClasses[0]
                 self.listOutputs.append('%s$%d' % (clazz, self.nextAnon))
-            elif self.version in ('1.5', '1.6'):
+            elif self.version in ('1.5', '1.6', '1.7', '5', '6'):
                 self.stackAnonClassBrackets.append(self.brackets)
                 className = []
                 className.extend(self.listClasses)
                 self.__getAnonStack()[-1] = self.__getAnonStack()[-1] + 1
                 for anon in self.__getAnonStack():
                     className.append(str(anon))
-                self.listOutputs.append(string.join(className, '$'))
+                self.listOutputs.append('$'.join(className))
 
             self.nextAnon = self.nextAnon + 1
             self.__getAnonStack().append(0)
@@ -184,7 +186,7 @@ if java_parsing:
         def setPackage(self, package):
             self.package = package
 
-    class AnonClassState:
+    class AnonClassState(object):
         """A state that looks for anonymous inner classes."""
         def __init__(self, old_state):
             # outer_state is always an instance of OuterState
@@ -219,7 +221,7 @@ if java_parsing:
                 self.outer_state.addAnonClass()
             return self.old_state.parseToken(token)
 
-    class SkipState:
+    class SkipState(object):
         """A state that will skip a specified number of tokens before
         reverting to the previous state."""
         def __init__(self, tokens_to_skip, old_state):
@@ -231,7 +233,7 @@ if java_parsing:
                 return self.old_state
             return self
 
-    class ClassState:
+    class ClassState(object):
         """A state we go into when we hit a class or interface keyword."""
         def __init__(self, outer_state):
             # outer_state is always an instance of OuterState
@@ -240,11 +242,25 @@ if java_parsing:
             # the next non-whitespace token should be the name of the class
             if token == '\n':
                 return self
+            # If that's an inner class which is declared in a method, it
+            # requires an index prepended to the class-name, e.g.
+            # 'Foo$1Inner' (Tigris Issue 2087)
+            if self.outer_state.localClasses and \
+                self.outer_state.stackBrackets[-1] > \
+                self.outer_state.stackBrackets[-2]+1:
+                locals = self.outer_state.localClasses[-1]
+                try:
+                    idx = locals[token]
+                    locals[token] = locals[token]+1
+                except KeyError:
+                    locals[token] = 1
+                token = str(locals[token]) + token
+            self.outer_state.localClasses.append({})
             self.outer_state.listClasses.append(token)
             self.outer_state.anonStacksStack.append([0])
             return self.outer_state
 
-    class IgnoreState:
+    class IgnoreState(object):
         """A state that will ignore all tokens until it gets to a
         specified token."""
         def __init__(self, ignore_until, old_state):
@@ -255,7 +271,7 @@ if java_parsing:
                 return self.old_state
             return self
 
-    class PackageState:
+    class PackageState(object):
         """The state we enter when we encounter the package keyword.
         We assume the next token will be the package name."""
         def __init__(self, outer_state):
@@ -281,7 +297,7 @@ if java_parsing:
             currstate = currstate.parseToken(token)
             if trace: trace(token, currstate)
         if initial.package:
-            package = string.replace(initial.package, '.', os.sep)
+            package = initial.package.replace('.', os.sep)
         return (package, initial.listOutputs)
 
 else:
@@ -299,3 +315,9 @@ else:
         the path to the file is the same as the package name.
         """
         return os.path.split(file)
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
